# Visonic Alarm Panel Library using asyncio

## Information
A Custom Integration Library to support the Visonic Integration.

The PowerLink hardware device is NOT a requirement for this library to work. Please do not use this library with a Powerlink hardware device.

Visonic produce the Powermax and Powermaster alarm panel series.

This library supports PowerMax+, PowerMaxExpress, PowerMaxPro and PowerMaxComplete, PowerMaster 10 and PowerMaster 30.

This library connects directly to the panel using a simple piece of hardware, please see the wiki for further information.

An extensive test example is included using the aconsole pypi library.

## Installation
sudo pip3 install pyvisonic

## Wiki
Remember to check out the Wiki, this contains all the documentation and the hardware that you will need.

- [Wiki Home](https://github.com/davesmeghead/visonic/wiki)

## Release
This Component is compliant with the new Component format within the Home Assistant structure.
